.. phmdoctest documentation master file, created by
   sphinx-quickstart on Thu Mar 26 20:52:19 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

phmdoctest 0.0.6
================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   doc/recent_changes
   doc/api
   doc/about

   
Search
======

* :ref:`search`